---
name: Bug Report
about: Any general feedback or bug reports about the Vyper Compiler. No new features proposals.
---

### Version Information

* vyper Version (output of `vyper --version`): x.x.x
* OS: osx/linux/win
* Python Version (output of `python --version`):

### What's your issue about?

Please include information like:

* full output of the error you received
* what command you ran
* the code that caused the failure (see [this link](https://help.github.com/articles/basic-writing-and-formatting-syntax/) for help with formatting code)
* please try running your example with the `--verbose` flag turned on


### How can it be fixed?

Fill this in if you know how to fix it.
